#!/usr/bin/env python3

import pathlib
from miyadaiku import setuputils

DIR = pathlib.Path(__file__).resolve().parent

srcdir = DIR / 'node_modules/bootstrap/dist'
destdir = DIR / 'miyadaiku_theme_bootstrap4/externals'
copy_files = [
    [srcdir/ 'css/', ['bootstrap.css', 'bootstrap.min.css', ], destdir / 'css/'],
    [srcdir / 'js/', ['bootstrap.css', '*.js', ], destdir / 'js/']
]

setuputils.copyfiles(copy_files)



import pytest
import pathlib

import miyadaiku.core
import miyadaiku.core.site  # install pyyaml converter

#miyadaiku.core.SHOW_TRACEBACK = True
#miyadaiku.core.DEBUG = True

from miyadaiku.core.site import Site

@pytest.fixture
def sitedir(tmpdir):
    d = tmpdir.mkdir('site')
    d.mkdir('contents')
    d.mkdir('templates')
    return pathlib.Path(str(d))

def test_install(sitedir):
    (sitedir / 'config.yml').write_text('''
themes:
    - miyadaiku.themes.bootstrap4

''')

    (sitedir /'contents/index.rst').write_text('''

test
---------------

abc 

.. jinja::

   {{ bootstrap4.load_css(page) }}
   {{ bootstrap4.load_js(page) }}
''')

    site = Site(sitedir)
    site.build()

    ret = (sitedir / 'outputs/index.html').read_text()

    assert '<link href="static/bootstrap4/bootstrap.min.css" rel="stylesheet"/>' in ret
    assert '<script src="static/bootstrap4/bootstrap.min.js"></script>' in ret

    assert (sitedir / 'outputs/static/bootstrap4/bootstrap.min.css').exists()
    assert (sitedir / 'outputs/static/bootstrap4/bootstrap.min.js').exists()



import pkg_resources

from . __version__ import __version__

CSS_MIN = 'bootstrap.min.css'
CSS = 'bootstrap.css'

JS_MIN = 'bootstrap.min.js'
JS = 'bootstrap.js'

DEST_PATH = '/static/bootstrap4/'

def load_package(site):
    f = site.config.getbool('/', 'bootstrap4_compressed')

    css = CSS_MIN if f else CSS
    css_path = 'externals/css/'+css

    content = pkg_resources.resource_string(__name__, css_path)
    site.files.add_bytes("binary", DEST_PATH + css, content )
    site.config.add('/', {'bootstrap4_css_path': DEST_PATH+css})


    js = JS_MIN if f else JS
    js_path = 'externals/js/'+js
    
    content = pkg_resources.resource_string(__name__, js_path)
    site.files.add_bytes("binary", DEST_PATH + js, content )
    site.config.add('/', {'bootstrap4_js_path': DEST_PATH+js})

    site.add_template_module('bootstrap4', 'miyadaiku_theme_bootstrap4!macros.html')

